#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys

from mastodon_toot_follower import mastodon_util
from mastodon_toot_follower.mastodon_factory import MastodonFactory
from mastodon_toot_follower.conversation.conversation import Conversation


def main():
    if len(sys.argv) != 2:
        usage()
    toot_url = sys.argv[1]

    try:
        instance_url, username, toot_id = mastodon_util.parse_toot_url(url=toot_url)
    except Exception as e:
        print(e, file=sys.stderr)
        usage()

        instance_url, username, toot_id = None, None, None  # Fix IDE Warnings

    mastodon_factory = MastodonFactory()
    conversation = Conversation(mastodon_factory=mastodon_factory,
                                mastodon_instance=instance_url,
                                toot_id=toot_id)
    reading_position = conversation.get_and_update_reading_position('local_user')

    print(f'Reading position: {reading_position}')
    print(f'Conversation length: {conversation.conversation_length()}')
    new_updates = conversation.updates(reading_position=reading_position)
    if len(new_updates) == 0:
        print('There is no news from the conversation.')
    else:
        print(f'News from the conversation:\n')
        print('\n'.join([str(update) for update in new_updates]))


def usage():
    print(f'\n'
          f'usage: {sys.argv[0]} MASTODON_TOOT_URL\n'
          f'example: {sys.argv[0]} https://mastodon.instance/@user@another.instance/123456', file=sys.stderr)
    exit(1)


if __name__ == '__main__':
    main()
