from pathlib import Path

from mastodon import Mastodon


def main():
    app_name = 'MastodonTootFollower'
    git_url = 'https://codeberg.org/privacy1st/MastodonTootFollower'
    app_credentials = Path(app_name + '.secret')

    instance_url = 'https://replace-with-existing-instance'

    # Create application credentials only once.
    if not app_credentials.exists():
        client_id, client_secret = Mastodon.create_app(
            client_name=app_name,
            website=git_url,
            api_base_url=instance_url,
            to_file=app_credentials,
            scopes=['read']
        )

    # Create Mastdon API wrapper object.
    # Optionally, log in.
    #
    # Copied from __init__:
    #         Create a new API wrapper instance based on the given `client_secret` and `client_id` on the
    #         instance given by `api_base_url`. If you give a `client_id` and it is not a file, you must
    #         also give a secret. If you specify an `access_token` then you don't need to specify a `client_id`.
    #         It is allowed to specify neither - in this case, you will be restricted to only using endpoints
    #         that do not require authentication. If a file is given as `client_id`, client ID, secret and
    #         base url are read from that file.
    mastodon = Mastodon(client_id=app_credentials)
    # mastodon.log_in(
    #     username='my_login_email@example.com',
    #     password='incrediblygoodpassword',
    #     to_file='pytooter_usercred.secret'
    # )

    test_status_info(mastodon, 'https://replace-with-existing-toot-url')


def test_status_info(mastodon: Mastodon, status_url: str, cache_dir: Path = Path('cache')) -> None:
    # Example: https://mastodon.instance/@user@another.instance/123456

    prefix = 'https://'
    if not status_url.startswith(prefix):
        raise ValueError(status_url)
    status_url = status_url[len(prefix):]
    status_url_parts = status_url.split('/')
    if len(status_url_parts) != 3:
        raise ValueError(status_url)

    instance_url, username, status_id = status_url_parts

    # Returns information about the given status.
    # - number of replies
    # result = mastodon.status(id=status_id)

    # Returns the following dictionary:
    # {
    #     'ancestors':  # A list of toot dicts
    #     'descendants':  # A list of toot dicts (including fields `id`, `created_at`, 'edited_at')
    # }
    result = mastodon.status_context(id=status_id)

    print(result)


if __name__ == '__main__':
    main()
